.. currentmodule:: sardana.pool.poolmeasurementgroup

:mod:`~sardana.pool.poolmeasurementgroup`
=========================================

.. automodule:: sardana.pool.poolmeasurementgroup

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolMeasurementGroup`


PoolInstrument
--------------

.. inheritance-diagram:: PoolMeasurementGroup
    :parts: 1
    
.. autoclass:: PoolMeasurementGroup
    :show-inheritance:
    :members:
    :undoc-members:

